package com.dcsoft.system.vehicle.mapper;

import com.dcsoft.system.vehicle.domain.CarParkRecord;

import java.util.List;

/**
 * 车辆授权Mapper接口
 *
 * @author dcsoft
 * @date 2023-12-29
 */
public interface CarParkRecordMapper
{
    /**
     * 查询车辆授权
     *
     * @param id 车辆授权主键
     * @return 车辆授权
     */
    public CarParkRecord selectCarParkRecordById(Long id);

    /**
     * 查询车辆授权列表
     *
     * @param carParkRecord 车辆授权
     * @return 车辆授权集合
     */
    public List<CarParkRecord> selectCarParkRecordList(CarParkRecord carParkRecord);

    /**
     * 新增车辆授权
     *
     * @param carParkRecord 车辆授权
     * @return 结果
     */
    public int insertCarParkRecord(CarParkRecord carParkRecord);

    /**
     * 修改车辆授权
     *
     * @param carParkRecord 车辆授权
     * @return 结果
     */
    public int updateCarParkRecord(CarParkRecord carParkRecord);

    /**
     * 删除车辆授权
     *
     * @param id 车辆授权主键
     * @return 结果
     */
    public int deleteCarParkRecordById(Long id);

    /**
     * 批量删除车辆授权
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCarParkRecordByIds(Long[] ids);

    public int deleteCarParkRecordByParkId(Long parkId);

    public int deleteCarParkRecordByCustomerIds(Long[] ids);

    public int deleteCarParkRecordByCustomerId(Long[] ids);

    public int deleteCarParkRecordByCustomerId(Long customerId);
}
